@@ -1,5 +1,3 @@
-from abc import abstractmethod
-
 from .auth_source_connection import AuthSourceConnection
 
 
@@ -10,12 +8,10 @@ class SessionSourceConnection(AuthSourceConnection):
     `open` method instead.
     '''
 
-    @abstractmethod
     def open(self: 'SessionSourceConnection') -> bool:
         '''Opens a session attached to this connection.'''
         return True
 
-    @abstractmethod
     def close(self: 'SessionSourceConnection') -> bool:
         '''Closes the attached session'''
         return True
